#!/usr/bin/env python
"""
Command-line entry point for katachi.
This allows running the package directly with `python -m katachi`.
"""

from katachi.cli import app

if __name__ == "__main__":
    app()
